\name{lagNorm}
\alias{lagNorm}
\title{Wrapper Function for Normalization Procedure}
\description{
  Performs normalization from \cite{Peng et al. (2007)} and plots process similar to figure 6 from that paper.
}
\usage{
lagNorm(MA, nlag = 8, group = NULL, w = 1, w.cut=0.5, lr.out = 2, ma.out = 2, npoints=6000, plot.names = paste("MAplots_", colnames(MA$M), sep = ""), ...)
}
\arguments{
  \item{MA}{object with components \code{M} and \code{A} (which can be accessed through \code{MA$M} and \code{MA$A}, respectively), and possibly others.}
  \item{nlag}{integer between \code{1} and \code{nrow(MA$M)-1}. Probes tiled this far apart are subtracted in order to compute angle.}
  \item{group}{optional vector with length equal to the number of probes (i.e., equal to the number of rows of \code{M} and \code{A}) indicating which group each probe belongs to.}
  \item{w}{numeric matrix of spot quality weights with elements between 0 (poor quality) and 1 (high quality), inclusive. If this is not a matrix with the same dimensions as \code{M} and \code{A}, elements will be recycled to make it so.}
  \item{w.cut}{numeric cut-off below 1. Probes with weight less than or equal to this will be excluded from angle computation.} 
  \item{lr.out}{numeric standard deviations from median. Rotated log ratios beyond this will be given no weight in final loess fit.}
  \item{ma.out}{numeric distance from center of mass on MA-plot of differences. Points beyond this will be given no weight  
  in angle computation. Squared Euclidean distance is used after dividing by the average median absolute deviation in \code{M} and \code{A}.}
  \item{npoints}{numeric quantity of probes from each chip to be plotted. If this value is less than the number of rows in \code{M} and \code{A} (i.e., the number of probes) a random set of size \code{npoints} is selected. Otherwise, all points are plotted.}
  \item{plot.names}{names of PNG files sent to working directory. Set this to \code{NULL} to avoid plotting. If this is not \code{NULL}, then it must have length equal to the number of chips, i.e., \code{ncol(MA$M)}.}
  \item{\dots}{arguments sent to \code{\link{plot}}.}
}
\details{
  Plots are created unless \code{plot.names=NULL}. These plots do not exclude points based on weight and may take a while when the number of points plotted is large. 
}
\value{
  Normalized \code{MA} object. Only components \code{M} and \code{A} are altered from input \code{MA} object.
}
\references{Shouyong Peng, Artyom A Alekseyenko, Erica Larschan, Mitzi I Kuroda, and Peter J Park. Normalization and experimental design for ChIP-chip data. \emph{BMC Bioinformatics}, 8(219), 2007.}
\author{Jonathan Dreyfuss and Shouyong Peng}
\examples{
#this example closely follows the vignette, where there is more explanation.
data(MSLdata)
#check noise for 1st chip
noise.mat <- lagNoise(MA = MA.ex, chip = 1, group=grp)

##normalize:
#a. using wrapper lagNorm
MA.norm <- lagNorm(MA = MA.ex, nlag = 8, plot.names=NULL)

#b. directly using getAngle & rotateMA, followed by your own loess-type smooth
angle <- getAngle(MA = MA.ex, nlag = 8)
MA.rot <- rotateMA(MA = MA.ex, angle = angle)
#create MA.norm from your own loess-type smooth on MA.rot
}
\keyword{array}
\keyword{dplot}
\keyword{hplot}
\keyword{algebra}
\keyword{smooth}
\keyword{loess}

